# Pypeliner

![build](https://travis-ci.org/shahcompbio/pypeliner.svg?branch=master)

## What is Pypeliner?

Pypeliner is a library for creating informatic workflows or pipelines. It aims
to reduce the amount boilerplate code required to write a robust pipeline.

## Where are the docs?

Go to http://pypeliner.readthedocs.org/en/latest/ for the latest documentation.

## Where are the tests?

We currently have unittests for many of the use cases of the Scheduler class,
and these cover a majority of the functionality of Pypeliner.

```
python test/scheduler_test.py
```
